package com.ynet.life.timezone;

import com.ynet.gene.accesscontrol.GENEAccessController;
import com.ynet.gene.core.Context;
import com.ynet.gene.core.GENEException;
import com.ynet.gene.data.DataField;
import com.ynet.gene.data.IndexedCollection;
import com.ynet.gene.data.KeyedCollection;
import com.ynet.gene.log.GENELog;
import com.ynet.life.base.LifeStandard;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.TimeZone;

/* loaded from: com_ynet_life_timezone.jar:com/ynet/life/timezone/TimeZoneTransAccessController.class */
public class TimeZoneTransAccessController extends GENEAccessController {
    SimpleDateFormat dateformat;
    String format = "yyyyMMddHHmmss";
    String enableTrxs = null;

    public void initialize() {
        this.dateformat = new SimpleDateFormat(this.format);
        TimeZone tz = TimeZone.getDefault();
        this.dateformat.setTimeZone(tz);
        GENELog.log("TIMEZONE", GENELog.INFO, 0, "Server timezone is: ".concat(String.valueOf(tz)));
    }

    public Object checkAccess(Context context, Object requestObject, String accessItemId) throws GENEException {
        if (this.enableTrxs == null) {
            try {
                String bankSettingsValue = LifeStandard.getBankSettingsValue("TimeZoneExchangeTrxs");
                String enableTrxs = bankSettingsValue;
                if (!bankSettingsValue.startsWith(",")) {
                    enableTrxs = ",".concat(String.valueOf(enableTrxs));
                }
                if (!enableTrxs.endsWith(",")) {
                    enableTrxs = String.valueOf(enableTrxs) + ",";
                }
                this.enableTrxs = enableTrxs;
            } catch (Exception unused) {
            }
        }
        if (this.enableTrxs != null && this.enableTrxs.indexOf("," + accessItemId + ",") == -1) {
            return null;
        }
        return context;
    }

    public void beginAccess(Object obj) {
        Context context = (Context) obj;
        String timezone = (String) context.get("timezone");
        if (timezone == null) {
            return;
        }
        SimpleDateFormat clientdateformat = new SimpleDateFormat(this.format);
        TimeZone tz = TimeZone.getTimeZone(timezone);
        clientdateformat.setTimeZone(tz);
        GENELog.log("TIMEZONE", GENELog.INFO, 0, "Client timezone is: " + tz + " (" + timezone + ")");
        KeyedCollection kColl = (KeyedCollection) context.getDataElement();
        processKcoll(clientdateformat, kColl, true);
    }

    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r0v11, types: [boolean] */
    /* JADX WARN: Type inference failed for: r0v7, types: [java.lang.Object, java.lang.String] */
    /* JADX WARN: Type inference failed for: r0v8, types: [java.lang.Exception] */
    protected void processKcoll(SimpleDateFormat clientdateformat, KeyedCollection kColl, boolean input) {
        for (?? r0 : kColl.keySet()) {
            try {
                IndexedCollection dataElement = kColl.getDataElement((String) r0);
                r0 = dataElement instanceof DataField;
                if (r0 != 0) {
                    String dataType = ((DataField) dataElement).getDataType();
                    if ("timezone".equals(dataType)) {
                        if (input) {
                            String value = (String) kColl.get((Object) r0);
                            Date date = clientdateformat.parse(value);
                            String value2 = this.dateformat.format(date);
                            kColl.put((Object) r0, value2);
                        } else {
                            String value3 = (String) kColl.get((Object) r0);
                            Date date2 = this.dateformat.parse(value3);
                            String value4 = clientdateformat.format(date2);
                            kColl.put((Object) r0, value4);
                        }
                    }
                } else if (dataElement instanceof KeyedCollection) {
                    processKcoll(clientdateformat, (KeyedCollection) dataElement, input);
                } else if (dataElement instanceof IndexedCollection) {
                    IndexedCollection iColl = dataElement;
                    for (int i = 0; i < iColl.size(); i++) {
                        KeyedCollection innerKColl = (KeyedCollection) iColl.get(i);
                        processKcoll(clientdateformat, innerKColl, input);
                    }
                }
            } catch (Exception e) {
                r0.printStackTrace();
            }
        }
    }

    public void endAccess(Object obj, long beginTimeStamp) {
        Context context = (Context) obj;
        String timezone = (String) context.get("timezone");
        if (timezone == null) {
            return;
        }
        SimpleDateFormat clientdateformat = new SimpleDateFormat(this.format);
        clientdateformat.setTimeZone(TimeZone.getTimeZone(timezone));
        KeyedCollection kColl = (KeyedCollection) context.getDataElement();
        processKcoll(clientdateformat, kColl, false);
    }

    public String getFormat() {
        return this.format;
    }

    public void setFormat(String format) {
        this.format = format;
    }
}
